# -*- coding: utf-8 -*-
from .app_settings import AppSettings


def welcome_text(request):
    conf = AppSettings()
    return {
        'DAT_WELCOME_TITLE': conf.DAT_WELCOME_TITLE,
        'DAT_WELCOME_TITLE_MOBILE': conf.DAT_WELCOME_TITLE_MOBILE,
        'DAT_WELCOME_TEXT': conf.DAT_WELCOME_TEXT,
    }



# -*- coding: utf-8 -*-
from django.conf import settings


class AppSettings(object):
    @property
    def DAT_WELCOME_TITLE(self):
        return getattr(settings, "DAT_WELCOME_TITLE", "Welcome")

    @property
    def DAT_WELCOME_TITLE_MOBILE(self):
        return getattr(settings, "DAT_WELCOME_TITLE_MOBILE", "Welcome mobile")

    @property
    def DAT_WELCOME_TEXT(self):
        return getattr(settings, "DAT_WELCOME_TEXT",
                       "Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor"
                       " invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua")



from allauth.account.forms import SignupForm
from django.conf import settings
from django.forms import CheckboxInput, BooleanField
from django.utils.safestring import mark_safe


class CustomSignupForm(SignupForm):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.fields["tos"] = BooleanField(
            label=mark_safe(settings.TOS_MESSAGE),
            widget=CheckboxInput(attrs={'class': 'text-gray-700 text-sm'}), required=True
        )



from django.urls import path, include, re_path
from django.views.defaults import page_not_found

from .views import CustomSignupView, CustomLoginView, CustomLogoutView, CustomPasswordSetView, \
    CustomPasswordChangeView, CustomEmailVerificationSentView, CustomConfirmEmailView, CustomAccountInactiveView, \
    CustomPasswordResetView, CustomPasswordResetDoneView, CustomPasswordResetFromKeyView, \
    CustomPasswordResetFromKeyDoneView

urlpatterns = [
    path("accounts/signup/", CustomSignupView.as_view(), name="account_signup"),
    path("accounts/email/", page_not_found, kwargs={"exception": Exception("Page not Found")}),
    path("accounts/login/", CustomLoginView.as_view(), name="account_login"),
    path("accounts/logout/", CustomLogoutView.as_view(), name="account_logout"),
    path("accounts/password/change/", CustomPasswordChangeView.as_view(), name="account_change_password"),
    path("accounts/password/set/", CustomPasswordSetView.as_view(), name="account_set_password"),
    path("accounts/inactive/", CustomAccountInactiveView.as_view(), name="account_inactive"),
    path("accounts/confirm-email/", CustomEmailVerificationSentView.as_view(), name="account_email_verification_sent"),
    re_path(r"^accounts/confirm-email/(?P<key>[-:\w]+)/$", CustomConfirmEmailView.as_view(),
            name="account_confirm_email"),
    path("accounts/password/reset/", CustomPasswordResetView.as_view(), name="account_reset_password"),
    path("accounts/password/reset/done/", CustomPasswordResetDoneView.as_view(), name="account_reset_password_done"),
    re_path(r"^accounts/password/reset/key/(?P<uidb36>[0-9A-Za-z]+)-(?P<key>.+)/$",
            CustomPasswordResetFromKeyView.as_view(), name="account_reset_password_from_key"),
    path("accounts/password/reset/key/done/", CustomPasswordResetFromKeyDoneView.as_view(),
         name="account_reset_password_from_key_done"),
    path('accounts/', include('allauth.urls')),
]



from allauth.account.views import SignupView, LoginView, LogoutView, PasswordSetView, PasswordChangeView, \
    ConfirmEmailView, EmailVerificationSentView, AccountInactiveView, PasswordResetView, PasswordResetDoneView, \
    PasswordResetFromKeyView, PasswordResetFromKeyDoneView
from allauth.decorators import rate_limit
from django.contrib.auth.mixins import LoginRequiredMixin
from django.utils.decorators import method_decorator
from django.views.generic import TemplateView

from .forms import CustomSignupForm


@method_decorator(rate_limit(action="signup"), name="dispatch")
class CustomSignupView(SignupView):
    form_class = CustomSignupForm
    template_name = 'allauth/account/signup.html'


class CustomLoginView(LoginView):
    template_name = 'allauth/account/login.html'


class CustomLogoutView(LogoutView):
    template_name = 'allauth/account/logout.html'


@method_decorator(
    # NOTE: 'change_password' (iso 'set_') is intentional, there is no need to
    # differentiate between set and change.
    rate_limit(action="change_password"),
    name="dispatch",
)
class CustomPasswordSetView(LoginRequiredMixin, PasswordSetView):
    template_name = 'allauth/account/password_set.html'


@method_decorator(rate_limit(action="change_password"), name="dispatch")
class CustomPasswordChangeView(LoginRequiredMixin, PasswordChangeView):
    template_name = 'allauth/account/password_change.html'


class CustomEmailVerificationSentView(EmailVerificationSentView):
    template_name = "allauth/account/verification_sent.html"


class CustomConfirmEmailView(ConfirmEmailView):
    template_name = "allauth/account/email_confirm.html"


class CustomAccountInactiveView(AccountInactiveView):
    template_name = "allauth/account/account_inactive.html"


@method_decorator(rate_limit(action="reset_password"), name="dispatch")
class CustomPasswordResetView(PasswordResetView):
    template_name = "allauth/account/password_reset.html"


class CustomPasswordResetDoneView(PasswordResetDoneView):
    template_name = "allauth/account/password_reset_done.html"


@method_decorator(rate_limit(action="reset_password_from_key"), name="dispatch")
class CustomPasswordResetFromKeyView(PasswordResetFromKeyView):
    template_name = 'allauth/account/password_reset_from_key.html'


class CustomPasswordResetFromKeyDoneView(PasswordResetFromKeyDoneView):
    template_name = "allauth/account/password_reset_from_key_done.html"



from setuptools import setup, find_packages

version = __import__("allauth_theme").__version__

setup(
   name='django-allauth-theme',
   version=version,
   author='Leonardo Di Lella',
   author_email='leonardo.dilella@mobileapart.com',
   packages=find_packages(),
   keywords="django auth account social openid twitter facebook oauth registration theme tailwindcss",
   url='http://pypi.python.org/pypi/django-allauth-theme/',
   license='LICENSE',
   description='An Awesome django-allauth theme based on tailwind',
   long_description_content_type="text/markdown",
   long_description=open('README.md').read(),
   install_requires=[
        "Django >= 2.0",
        "django-allauth >= 0.51.0"
    ],
    python_requires=">=3.5",
    include_package_data=True,
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Environment :: Web Environment",
        "Topic :: Internet",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Framework :: Django",
        "Framework :: Django :: 2.0",
        "Framework :: Django :: 2.1",
        "Framework :: Django :: 2.2",
        "Framework :: Django :: 3.0",
        "Framework :: Django :: 3.1",
        "Framework :: Django :: 3.2",
        "Framework :: Django :: 4.0",
        "Framework :: Django :: 4.1",
   ]
)
